@@ -25,6 +25,7 @@ import java.io.IOException;
 
 import org.junit.Ignore;
 import org.junit.Test;
+import org.sejda.model.input.PdfSource;
 import org.sejda.model.output.ExistingOutputPolicy;
 import org.sejda.model.parameter.PageSize;
 import org.sejda.model.parameter.ResizePagesParameters;
@@ -45,15 +46,7 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void addUniformMargins() throws IOException {
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(regularInput());
-        parameters.setMargins(new Margins(1, 1, 1, 1));
-        parameters.addPageRange(new PageRange(1, 3));
-        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
-
-        testContext.pdfOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeAddMargins(new Margins(1, 1, 1, 1), new PageRange(1, 3), regularInput());
 
         // number of pages does not change
         testContext.assertPages(11).forEachPdfOutput(d -> {
@@ -83,15 +76,7 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void addMargins() throws IOException {
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(regularInput());
-        parameters.setMargins(new Margins(0, 0, 2, 5));
-        parameters.addPageRange(new PageRange(1, 3));
-        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
-
-        testContext.pdfOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeAddMargins(new Margins(0, 0, 2, 5), new PageRange(1, 3), regularInput());
 
         // number of pages does not change
         testContext.assertPages(11).forEachPdfOutput(d -> {
@@ -120,13 +105,7 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void landscape() throws IOException {
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/landscape.pdf"));
-        parameters.addSource(customInput("pdf/landscape_by_rotation.pdf"));
-        parameters.setPageSize(PageSize.A5);
-        testContext.directoryOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(PageSize.A5, customInput("pdf/landscape.pdf"), customInput("pdf/landscape_by_rotation.pdf"));
 
         testContext.forEachPdfOutput(d -> {
             PDPage page = d.getPage(0);
@@ -138,18 +117,12 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
     @Test
     public void potrait() throws IOException {
         // A4 to A3
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/potrait.pdf"));
-        parameters.addSource(customInput("pdf/potrait.pdf"));
-        parameters.setPageSize(PageSize.A3);
-        testContext.directoryOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(PageSize.A3, customInput("pdf/potrait.pdf"), customInput("pdf/potrait_by_rotation.pdf"));
 
         testContext.forEachPdfOutput(d -> {
             PDPage page = d.getPage(0);
-            assertEqualsRect(new PDRectangle(0, 0, 842, 1192), page.getCropBox().rotate(page.getRotation()));
-            assertEqualsRect(new PDRectangle(0, 0, 842, 1192), page.getMediaBox().rotate(page.getRotation()));
+            assertEqualsRect(PDRectangle.A3, page.getCropBox().rotate(page.getRotation()));
+            assertEqualsRect(PDRectangle.A3, page.getMediaBox().rotate(page.getRotation()));
         });
     }
 
@@ -157,19 +130,12 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void annotationsRectangleAndQuadPoints() throws IOException {
-
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/highlighted-potrait.pdf"));
-        parameters.setPageSize(annotPageSize);
-        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
-        testContext.pdfOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(annotPageSize, customInput("pdf/highlighted-potrait.pdf"));
 
         testContext.forPdfOutput(d -> {
             d.getPage(0).getAnnotations().forEach(a -> {
-                assertEqualsRect(new PDRectangle(117, 1588, 110, 26), a.getRectangle());
-                assertArrayEquals(new float[] { 117, 1614, 226, 1614, 117, 1588, 226, 1588 },
+                assertEqualsRect(new PDRectangle(117, 1584, 110, 26), a.getRectangle());
+                assertArrayEquals(new float[]{118, 1611, 227, 1611, 118, 1584, 227, 1584},
                         a.getCOSObject().getDictionaryObject(COSName.QUADPOINTS, COSArray.class).toFloatArray(), 1);
             });
 
@@ -178,19 +144,12 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void annotationsCallout() throws IOException {
-
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/callout-potrait.pdf"));
-        parameters.setPageSize(annotPageSize);
-        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
-        testContext.pdfOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(annotPageSize, customInput("pdf/callout-potrait.pdf"));
 
         testContext.forPdfOutput(d -> {
             d.getPage(0).getAnnotations().forEach(a -> {
-                assertEqualsRect(new PDRectangle(259, 1496, 496, 104), a.getRectangle());
-                assertArrayEquals(new float[] { 259, 1596, 507, 1510, 533, 1511 },
+                assertEqualsRect(new PDRectangle(259, 1492, 496, 104), a.getRectangle());
+                assertArrayEquals(new float[] { 260, 1592, 508, 1507, 533, 1507 },
                         a.getCOSObject().getDictionaryObject(COSName.CL, COSArray.class).toFloatArray(), 1);
             });
 
@@ -199,21 +158,14 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void annotationsPolygon() throws IOException {
-
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/polygon-potrait.pdf"));
-        parameters.setPageSize(annotPageSize);
-        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
-        testContext.pdfOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(annotPageSize, customInput("pdf/polygon-potrait.pdf"));
 
         testContext.forPdfOutput(d -> {
             d.getPage(0).getAnnotations().forEach(a -> {
                 if (a.getSubtype().equals("Polygon")) {
                     assertEqualsRect(new PDRectangle(431, 1218, 391, 351), a.getRectangle());
                     assertArrayEquals(
-                            new float[] { 454, 1503, 607, 1567, 799, 1523, 820, 1339, 576, 1221, 433, 1294, 454, 1503 },
+                            new float[]{454, 1499, 607, 1563, 798, 1519, 819, 1335, 575, 1218, 434, 1290, 454, 1499},
                             a.getCOSObject().getDictionaryObject(COSName.VERTICES, COSArray.class).toFloatArray(), 1);
                 }
             });
@@ -223,20 +175,13 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void annotationsLine() throws IOException {
-
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/line-potrait_by_rotation.pdf"));
-        parameters.setPageSize(annotPageSize);
-        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
-        testContext.pdfOutputTo(parameters);
-        execute(parameters);
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(annotPageSize, customInput("pdf/line-potrait_by_rotation.pdf"));
 
         testContext.forPdfOutput(d -> {
             d.getPage(0).getAnnotations().forEach(a -> {
                 if (a.getSubtype().equals("Line")) {
                     assertEqualsRect(new PDRectangle(1584, 884, 49, 220), a.getRectangle());
-                    assertArrayEquals(new float[] { 1600, 1092, 1609, 897 },
+                    assertArrayEquals(new float[]{1598, 1089, 1606, 895},
                             a.getCOSObject().getDictionaryObject(COSName.L, COSArray.class).toFloatArray(), 1);
                 }
             });
@@ -246,16 +191,7 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void resize_MultipleSizedPages_MixingLandscapePortrait() throws IOException {
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/multiple-sized-pages.pdf"));
-        parameters.setPageSize(PageSize.A5);
-        parameters.addPageRange(new PageRange(1, 2));
-
-        testContext.directoryOutputTo(parameters);
-
-        execute(parameters);
-
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(PageSize.A5, new PageRange(1, 2), customInput("pdf/multiple-sized-pages.pdf"));
 
         // number of pages does not change
         testContext.assertPages(3).forEachPdfOutput(d -> {
@@ -276,7 +212,8 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
             page = d.getPage(2);
 
-            // page has unchanged size
+            // page has unchanged size,
+            // because it was not included in the page selection
             expected = new PDRectangle(0f, 0f, 841f, 1190f);
             assertEqualsRect(expected, page.getMediaBox());
             assertEqualsRect(expected, page.getCropBox());
@@ -285,15 +222,7 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void resize_allLandscape() throws IOException {
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/multiple-sized-pages-all-landscape.pdf"));
-        parameters.setPageSize(PageSize.A5);
-
-        testContext.directoryOutputTo(parameters);
-
-        execute(parameters);
-
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(PageSize.A5, customInput("pdf/multiple-sized-pages-all-landscape.pdf"));
 
         // number of pages does not change
         testContext.assertPages(2).forEachPdfOutput(d -> {
@@ -301,14 +230,13 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
             // page has new size
             // was A4 landscape, expect A5 landscape
-            PDRectangle expected = PDRectangle.A5.rotate(90);
+            PDRectangle expected = PDRectangle.A5.rotate();
             assertEqualsRect(expected, page.getMediaBox());
             assertEqualsRect(expected, page.getCropBox());
 
             page = d.getPage(1);
             // page has new size
             // was A3 landscape, expect A5 landscape
-            expected = PDRectangle.A5.rotate(90);
             assertEqualsRect(expected, page.getMediaBox());
             assertEqualsRect(expected, page.getCropBox());
         });
@@ -316,15 +244,7 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
 
     @Test
     public void noPageSelection() throws IOException {
-        ResizePagesParameters parameters = new ResizePagesParameters();
-        parameters.addSource(customInput("pdf/test-pdf.pdf"));
-        parameters.setPageSize(PageSize.A5);
-
-        testContext.directoryOutputTo(parameters);
-
-        execute(parameters);
-
-        testContext.assertTaskCompleted();
+        executeChangeOfPageSize(PageSize.A5, customInput("pdf/test-pdf.pdf"));
 
         testContext.forEachPdfOutput(d -> {
             // all pages have new size of A5
@@ -354,6 +274,59 @@ public abstract class ResizePagesTaskTest extends BaseTaskTest<ResizePagesParame
         });
     }
 
+    @Test
+    public void resizeChangingAspectRatio() throws IOException {
+        executeChangeOfPageSize(PageSize.LEGAL, customInput("pdf/test-pdf.pdf"));
+
+        testContext.forEachPdfOutput(d -> {
+            PDPage page = d.getPage(0);
+            assertEqualsRect(PDRectangle.LEGAL, page.getMediaBox());
+            assertEqualsRect(PDRectangle.LEGAL, page.getCropBox());
+        });
+    }
+
+    private void executeChangeOfPageSize(PageSize desiredPageSize, PdfSource<?>... inputs) throws IOException {
+        executeChangeOfPageSize(desiredPageSize, null, inputs);
+    }
+
+    private void executeChangeOfPageSize(PageSize desiredPageSize, PageRange pageRange, PdfSource<?>... inputs) throws IOException {
+        ResizePagesParameters parameters = new ResizePagesParameters();
+        for(PdfSource<?> input: inputs) {
+            parameters.addSource(input);
+        }
+
+        parameters.setPageSize(desiredPageSize);
+        if(pageRange != null) {
+            parameters.addPageRange(pageRange);
+        }
+
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+        testContext.directoryOutputTo(parameters);
+
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+    }
+
+    private void executeAddMargins(Margins margins, PageRange pageRange, PdfSource<?>... inputs) throws IOException {
+        ResizePagesParameters parameters = new ResizePagesParameters();
+        for(PdfSource<?> input: inputs) {
+            parameters.addSource(input);
+        }
+
+        parameters.setMargins(margins);
+        if(pageRange != null) {
+            parameters.addPageRange(pageRange);
+        }
+
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+        testContext.directoryOutputTo(parameters);
+
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+    }
+
     private String extractText(PDPage page, Rectangle rect) {
         try {
             PDFTextStripperByArea stripper = new PDFTextStripperByArea();
