@@ -82,12 +82,18 @@ public class PdfScaler {
     public void scalePages(PDDocument doc, Iterable<PDPage> pages, PDRectangle targetBox) throws TaskIOException {
         for (PDPage page : pages) {
             PDRectangle cropBox = page.getCropBox().rotate(page.getRotation());
-            double scale = getScalingFactor(targetBox, cropBox);
+            double scale = getScalingFactorMatchWidth(targetBox, cropBox);
             LOG.debug("Scaling page from {} to {}, factor of {}", cropBox, targetBox, scale);
             scale(doc, page, scale);
         }
     }
 
+    public void changePageSize(PDDocument doc, Iterable<PDPage> pages, PDRectangle desiredPageSize) throws TaskIOException {
+        for (PDPage page : pages) {
+            changePageSize(doc, page, desiredPageSize);
+        }
+    }
+
     public void scale(PDDocument doc, double scale) throws TaskIOException {
         scale(doc, doc.getPages(), scale);
     }
@@ -102,6 +108,54 @@ public class PdfScaler {
         }
     }
 
+    public void changePageSize(PDDocument doc, PDPage page, PDRectangle desiredPageSize) throws TaskIOException {
+        PDRectangle currentPageSize = page.getCropBox().rotate(page.getRotation());
+        LOG.debug("Current page size: {}", currentPageSize);
+        LOG.debug("Desired page size: {}", desiredPageSize);
+
+        // first we scale the page to fit the new desired size
+        double scale = getScalingFactorMatchWidthOrHeight(desiredPageSize, currentPageSize);
+        doScale(doc, Collections.singletonList(page), scale);
+
+        // if the aspect ratio for the current size and new desired size are the same -> we are done
+        // otherwise, we need to add margins to reach the desired size
+
+        PDRectangle scaledPageSize = page.getCropBox().rotate(page.getRotation());
+        //LOG.debug("Scaled by {}", scale);
+
+        PDRectangle normalizedScaledPageSize = scaledPageSize;
+        boolean mismatchingOrientation = isLandscape(scaledPageSize) != isLandscape(desiredPageSize);
+        if(mismatchingOrientation) {
+            normalizedScaledPageSize = scaledPageSize.rotate();
+        }
+
+        //LOG.debug("Scaled page size:  {}", normalizedScaledPageSize);
+        //LOG.debug("Desired page size: {}", desiredPageSize);
+
+        double widthDiff = desiredPageSize.getWidth() - normalizedScaledPageSize.getWidth();
+        double heightDiff = desiredPageSize.getHeight() - normalizedScaledPageSize.getHeight();
+
+        //LOG.debug("Differences are widthDiff: {} heightDiff: {}", widthDiff, heightDiff);
+
+        if(widthDiff < 1) widthDiff = 0;
+        if(heightDiff < 1) heightDiff = 0;
+
+        if(widthDiff > 0 || heightDiff > 0) {
+            // Margins are in inches, not points
+            double top = Margins.pointsToInches(heightDiff) / 2;
+            double left = Margins.pointsToInches(widthDiff) / 2;
+            Margins margins = new Margins(top, left, top, left);
+            if(mismatchingOrientation) {
+                margins = margins.rotate();
+            }
+            margin(doc, Collections.singleton(page), margins);
+        }
+
+        PDRectangle finalPageSize = page.getCropBox().rotate(page.getRotation());
+        //LOG.debug("Final page size:   {}", finalPageSize);
+        //LOG.debug("Desired page size: {}", desiredPageSize);
+    }
+
     private void doScale(PDDocument doc, Iterable<PDPage> pages, double scale) throws TaskIOException {
         Set<COSDictionary> processedAnnots = new HashSet<>();
         for (PDPage page : pages) {
@@ -167,14 +221,10 @@ public class PdfScaler {
 
     /**
      * Adds the given margin all around the pages
-     * 
-     * @param doc
-     * @param pages
-     * @param margin
-     * @throws TaskIOException
      */
     public static void margin(PDDocument doc, Iterable<PDPage> pages, Margins margins) throws TaskIOException {
         if (nonNull(margins)) {
+            Set<COSDictionary> processedAnnots = new HashSet<>();
             for (PDPage page : pages) {
                 try (PDPageContentStream contentStream = new PDPageContentStream(doc, page, AppendMode.PREPEND, true)) {
                     page.setCropBox(addMargins(page.getCropBox().rotate(page.getRotation()), margins)
@@ -193,6 +243,8 @@ public class PdfScaler {
                     // realign the content
                     contentStream.transform(matrix);
 
+                    transformAnnotations(page, matrix, processedAnnots);
+
                 } catch (IOException e) {
                     throw new TaskIOException("An error occurred adding margins to the page.", e);
                 }
@@ -252,7 +304,11 @@ public class PdfScaler {
                 page.getMediaBox().transform(getMatrix(scale, page.getMediaBox(), page.getMediaBox())).getBounds2D()));
     }
 
-    private double getScalingFactor(PDRectangle targetBox, PDRectangle pageBox) {
+    /**
+     * Calculates the factor that pageBox can be scaled with to fit targetBox's **width** without overflow.
+     * For some pages this could mean that pageBox scaled will be taller than the targetBox.
+     */
+    private double getScalingFactorMatchWidth(PDRectangle targetBox, PDRectangle pageBox) {
         // if both target and page boxes have same orientation (landscape, portrait)
         // the scaling factor is targetWidth / pageWidth
         if(isLandscape(targetBox) == isLandscape(pageBox)) {
@@ -264,6 +320,27 @@ public class PdfScaler {
         }
     }
 
+    /**
+     * Calculates the factor that pageBox can be scaled with to fit targetBox without overflow.
+     * Ensures both height and width will not overflow targetBox.
+     */
+    private double getScalingFactorMatchWidthOrHeight(PDRectangle targetBox, PDRectangle pageBox) {
+        // if the boxes have different orientations
+        // we want to normalize first rotating the target 90 and then calculate scaling factors
+        // so landscape is scaled to a landscape
+        PDRectangle normalizedOrientationTargetBox = targetBox;
+        if(isLandscape(targetBox) != isLandscape(pageBox)) {
+            normalizedOrientationTargetBox = targetBox.rotate();
+        }
+
+        float widthFactor = normalizedOrientationTargetBox.getWidth() / pageBox.getWidth();
+        float heightFactor = normalizedOrientationTargetBox.getHeight() / pageBox.getHeight();
+
+        float factor = Math.min(widthFactor, heightFactor);
+        //LOG.debug("Factor: {} for normalizedOrientationTargetBox: {} pageBox: {}", factor, normalizedOrientationTargetBox, pageBox);
+        return factor;
+    }
+
     private boolean isLandscape(PDRectangle box) {
         return box.getWidth() > box.getHeight();
     }
