@@ -45,7 +45,7 @@ import org.sejda.sambox.pdmodel.font.PDFont;
 import org.sejda.sambox.pdmodel.font.PDType1Font;
 import org.sejda.sambox.pdmodel.interactive.annotation.PDAnnotation;
 import org.sejda.sambox.pdmodel.interactive.annotation.PDAnnotationLink;
-import org.sejda.sambox.pdmodel.interactive.documentnavigation.destination.PDPageFitWidthDestination;
+import org.sejda.sambox.pdmodel.interactive.documentnavigation.destination.PDPageXYZDestination;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -101,7 +101,7 @@ public class TableOfContentsCreator {
     }
 
     private PDAnnotationLink linkAnnotationFor(PDPage importedPage) {
-        PDPageFitWidthDestination pageDest = new PDPageFitWidthDestination();
+        PDPageXYZDestination pageDest = new PDPageXYZDestination();
         pageDest.setPage(importedPage);
         PDAnnotationLink link = new PDAnnotationLink();
         link.setDestination(pageDest);
@@ -113,19 +113,26 @@ public class TableOfContentsCreator {
      * Generates a ToC and prepend it to the given document
      */
     public void addToC() throws TaskException {
+        addToC(0);
+    }
+
+    /**
+     * Generates a ToC and inserts it in the doc at before the given page number
+     */
+    public void addToC(int beforePageNumber) throws TaskException {
         try {
             PDPageTree pagesTree = document.getPages();
             ofNullable(generateToC()).filter(l -> !l.isEmpty()).ifPresent(t -> {
                 int toCPagesCount = t.size();
                 t.descendingIterator().forEachRemaining(p -> {
                     if (pagesTree.getCount() > 0) {
-                        pagesTree.insertBefore(p, pagesTree.get(0));
+                        pagesTree.insertBefore(p, pagesTree.get(beforePageNumber));
                     } else {
                         pagesTree.add(p);
                     }
                 });
                 if (params.isBlankPageIfOdd() && toCPagesCount % 2 == 1) {
-                    PDPage lastTocPage = pagesTree.get(toCPagesCount - 1);
+                    PDPage lastTocPage = pagesTree.get(beforePageNumber + toCPagesCount - 1);
                     PDPage blankPage = new PDPage(lastTocPage.getMediaBox());
                     pagesTree.insertAfter(blankPage, lastTocPage);
                 }
@@ -181,8 +188,9 @@ public class TableOfContentsCreator {
                                 }
                             }
 
-                            String pageString = SEPARATOR + Long.toString(i.page + tocNumberOfPages);
-                            float x2 = getPageNumberX(separatorWidth, i.page + tocNumberOfPages);
+                            long pageNumber = i.page + tocNumberOfPages;
+                            String pageString = SEPARATOR + Long.toString(pageNumber);
+                            float x2 = getPageNumberX(separatorWidth, pageNumber);
                             writeText(page, pageString, x2, y);
 
                             // make the item clickable and link to the page number
