@@ -23,6 +23,8 @@ import org.sejda.impl.sambox.component.PageImageWriter;
 import org.sejda.model.exception.TaskException;
 import org.sejda.model.exception.TaskIOException;
 import org.sejda.model.input.Source;
+import org.sejda.model.parameter.PageOrientation;
+import org.sejda.model.parameter.PageSize;
 import org.sejda.sambox.pdmodel.PDPage;
 import org.sejda.sambox.pdmodel.common.PDRectangle;
 import org.sejda.sambox.pdmodel.graphics.image.PDImageXObject;
@@ -36,6 +38,11 @@ public class ImagesToPdfDocumentConverter {
 
     private static final Logger LOG = LoggerFactory.getLogger(ImagesToPdfDocumentConverter.class);
 
+    private PDRectangle pageSize = PDRectangle.A4;
+    private boolean shouldPageSizeMatchImageSize = false;
+    private PageOrientation pageOrientation = PageOrientation.AUTO;
+    private float marginInches = 0f;
+
     public PDDocumentHandler convert(List<Source<?>> sourceList) throws TaskException {
         PDDocumentHandler documentHandler = new PDDocumentHandler();
         documentHandler.setCreatorOnPDDocument();
@@ -46,23 +53,31 @@ public class ImagesToPdfDocumentConverter {
             beforeImage(source);
             try {
                 PDImageXObject image = PageImageWriter.toPDXImageObject(source);
-                PDRectangle mediaBox = PDRectangle.A4;
+                PDRectangle mediaBox = pageSize;
+                if(shouldPageSizeMatchImageSize) {
+                    mediaBox = new PDRectangle(image.getWidth(), image.getHeight());
+                }
 
-                if (image.getWidth() > image.getHeight() && image.getWidth() > mediaBox.getWidth()) {
+                if(pageOrientation == PageOrientation.LANDSCAPE) {
                     mediaBox = new PDRectangle(mediaBox.getHeight(), mediaBox.getWidth());
+                } else if(pageOrientation == PageOrientation.AUTO) {
+                    if (image.getWidth() > image.getHeight() && image.getWidth() > mediaBox.getWidth()) {
+                        LOG.debug("Switching to landscape, image dimensions are {}x{}", image.getWidth(), image.getHeight());
+                        mediaBox = new PDRectangle(mediaBox.getHeight(), mediaBox.getWidth());
+                    }
                 }
 
                 PDPage page = documentHandler.addBlankPage(mediaBox);
 
                 // full page (scaled down only)
-                int width = image.getWidth();
-                int height = image.getHeight();
+                float width = image.getWidth();
+                float height = image.getHeight();
 
                 if (width > mediaBox.getWidth()) {
                     int targetWidth = (int) mediaBox.getWidth();
                     LOG.debug("Scaling image down to fit by width {} vs {}", width, targetWidth);
 
-                    float ratio = (float) width / targetWidth;
+                    float ratio = width / targetWidth;
                     width = targetWidth;
                     height = Math.round(height / ratio);
                 }
@@ -76,11 +91,22 @@ public class ImagesToPdfDocumentConverter {
                     width = Math.round(width / ratio);
                 }
 
-                // centered on page
-                int x = ((int) mediaBox.getWidth() - width) / 2;
-                int y = ((int) mediaBox.getHeight() - height) / 2;
+                if(marginInches > 0) {
+                    float newWidth = width - marginInches * 72;
+                    float newHeight = height * newWidth / width;
+                    width = newWidth;
+                    height = newHeight;
+                }
 
-                imageWriter.append(page, image, new Point(x, y), width, height, null, 0);
+                // centered on page
+                float x = (mediaBox.getWidth() - width) / 2;
+                float y = ((int) mediaBox.getHeight() - height) / 2;
+
+                imageWriter.append(page, image, new Point((int)x, (int)y), width, height, null, 0);
+
+                // TODO: fix for stream source. it's the second time the source is read, will not work
+                int rotation = ExifHelper.getRotationBasedOnExifOrientation(source);
+                page.setRotation(rotation);
 
                 afterImage(image);
             } catch (TaskIOException e) {
@@ -102,4 +128,24 @@ public class ImagesToPdfDocumentConverter {
     public void failedImage(Source<?> source, TaskIOException e) throws TaskException {
 
     }
+
+    public void setPageSize(PageSize pageSize) {
+        this.pageSize = new PDRectangle(pageSize.getWidth(), pageSize.getHeight());
+    }
+
+    public void setPageSize(PDRectangle pageSize) {
+        this.pageSize = pageSize;
+    }
+
+    public void setShouldPageSizeMatchImageSize(boolean shouldPageSizeMatchImageSize) {
+        this.shouldPageSizeMatchImageSize = shouldPageSizeMatchImageSize;
+    }
+
+    public void setPageOrientation(PageOrientation pageOrientation) {
+        this.pageOrientation = pageOrientation;
+    }
+
+    public void setMarginInches(float marginInches) {
+        this.marginInches = marginInches;
+    }
 }
