@@ -18,8 +18,6 @@
  */
 package org.sejda.impl.sambox.component.optimization;
 
-import static java.util.Objects.isNull;
-import static java.util.Optional.of;
 import static java.util.Optional.ofNullable;
 
 import java.io.IOException;
@@ -28,29 +26,23 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Objects;
 import java.util.Optional;
-import java.util.function.Consumer;
 import java.util.stream.Collectors;
 
+import org.sejda.impl.sambox.component.ContentStreamProcessor;
 import org.sejda.impl.sambox.component.ReadOnlyFilteredCOSStream;
-import org.sejda.sambox.contentstream.PDFStreamEngine;
 import org.sejda.sambox.contentstream.operator.MissingOperandException;
 import org.sejda.sambox.contentstream.operator.Operator;
 import org.sejda.sambox.contentstream.operator.OperatorProcessor;
 import org.sejda.sambox.cos.COSBase;
 import org.sejda.sambox.cos.COSDictionary;
 import org.sejda.sambox.cos.COSName;
-import org.sejda.sambox.cos.COSNull;
 import org.sejda.sambox.cos.COSStream;
 import org.sejda.sambox.pdmodel.MissingResourceException;
-import org.sejda.sambox.pdmodel.PDPage;
 import org.sejda.sambox.pdmodel.font.PDType3CharProc;
 import org.sejda.sambox.pdmodel.font.PDType3Font;
 import org.sejda.sambox.pdmodel.graphics.PDXObject;
 import org.sejda.sambox.pdmodel.graphics.form.PDFormXObject;
 import org.sejda.sambox.pdmodel.graphics.form.PDTransparencyGroup;
-import org.sejda.sambox.pdmodel.interactive.annotation.PDAnnotation;
-import org.sejda.sambox.pdmodel.interactive.annotation.PDAppearanceEntry;
-import org.sejda.sambox.pdmodel.interactive.annotation.PDAppearanceStream;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -62,16 +54,16 @@ import org.slf4j.LoggerFactory;
  * @author Andrea Vacondio
  *
  */
-public class ResourcesHitter extends PDFStreamEngine implements Consumer<PDPage> {
+public class ResourcesHitter extends ContentStreamProcessor {
 
     private static final Logger LOG = LoggerFactory.getLogger(ResourcesHitter.class);
 
     public ResourcesHitter() {
-        addOperator(new XObjectOperator());
-        addOperator(new FontHitterOperator());
+        addOperator(new XObjectHitterOperator());
+        addOperator(new FontsHitterOperator());
     }
 
-    private class XObjectOperator extends OperatorProcessor {
+    public static class XObjectHitterOperator extends OperatorProcessor {
         @Override
         public void process(Operator operator, List<COSBase> operands) throws IOException {
             if (operands.isEmpty()) {
@@ -115,7 +107,14 @@ public class ResourcesHitter extends PDFStreamEngine implements Consumer<PDPage>
         }
     }
 
-    private class FontHitterOperator extends OperatorProcessor {
+    /**
+     * Tf operator that wraps a font dictionary with an {@link InUseFontDictionary} and puts it back to the resource dictionary so that we can later identify fonts that are
+     * actually used
+     * 
+     * @author Andrea Vacondio
+     *
+     */
+    public static class FontsHitterOperator extends OperatorProcessor {
         @Override
         public void process(Operator operator, List<COSBase> operands) throws IOException {
             if (operands.size() < 2) {
@@ -128,23 +127,21 @@ public class ResourcesHitter extends PDFStreamEngine implements Consumer<PDPage>
                         .map(r -> r.getCOSObject().getDictionaryObject(COSName.FONT, COSDictionary.class))
                         .filter(Objects::nonNull);
 
-                COSBase existing = fonts.map(d -> d.getDictionaryObject(fontName)).orElseThrow(
-                        () -> new MissingResourceException("Missing font resource: " + fontName.getName()));
+                COSDictionary fontDictionary = fonts.map(d -> d.getDictionaryObject(fontName, COSDictionary.class))
+                        .orElseThrow(() -> new MissingResourceException(
+                                "Font resource '" + fontName.getName() + "' missing or unexpected type"));
 
-                if (!(existing instanceof InUseFontDictionary)) {
-                    COSDictionary fontDictionary = of(existing).filter(e -> e instanceof COSDictionary)
-                            .map(e -> (COSDictionary) e)
-                            .orElseThrow(() -> new IllegalArgumentException("Font resource unexpected type"));
+                if (!(fontDictionary instanceof InUseFontDictionary)) {
 
                     LOG.trace("Hit font with name {}", fontName.getName());
                     // we wrap the existing so we can identify it later as "in use" and already processed
                     fonts.get().setItem(fontName, new InUseFontDictionary(fontDictionary));
 
-                    // type 3 fonts glyphs are content stream and they may refer to named resource. If the font resource dictionary is not present
-                    // the page resource dictionary is used instead so we have to make sure those resource are hit
-                    if (COSName.TYPE3.equals(fontDictionary.getCOSName(COSName.SUBTYPE))
-                            && isNull(fontDictionary.getItem(COSName.RESOURCES))) {
-                        LOG.trace("Found type3 font with no resource dictionary {}", fontName.getName());
+                    // type 3 fonts glyphs are content stream and they may refer to named resource.
+                    // If the font resource dictionary is not present the page resource dictionary is used instead AND
+                    // we cannot exclude the font resource is an indirect ref to the page resource dictionary
+                    // => so we have to make sure those resource are hit
+                    if (COSName.TYPE3.equals(fontDictionary.getCOSName(COSName.SUBTYPE))) {
                         PDType3Font font = new PDType3Font(fontDictionary);
                         Collection<COSBase> glyphStreams = ofNullable(
                                 fontDictionary.getDictionaryObject(COSName.CHAR_PROCS, COSDictionary.class))
@@ -153,8 +150,9 @@ public class ResourcesHitter extends PDFStreamEngine implements Consumer<PDPage>
                         List<PDType3CharProc> pdStreams = glyphStreams.stream().map(COSBase::getCOSObject)
                                 .filter(s -> s instanceof COSStream).map(s -> (COSStream) s)
                                 .map(s -> new PDType3CharProc(font, s)).collect(Collectors.toList());
+                        LOG.trace("Found type3 font {} with {} streams to parse", fontName.getName(), pdStreams.size());
                         for (PDType3CharProc glyph : pdStreams) {
-                            processStream(glyph);
+                            getContext().processStream(glyph);
                         }
                     }
                 }
@@ -166,34 +164,4 @@ public class ResourcesHitter extends PDFStreamEngine implements Consumer<PDPage>
             return "Tf";
         }
     }
-
-    private void processAnnotation(PDAnnotation annotation) throws IOException {
-        List<PDAppearanceEntry> appreaceEntries = ofNullable(annotation.getAppearance())
-                .map(d -> d.getCOSObject().getValues()).filter(Objects::nonNull).orElse(Collections.emptyList())
-                .stream().map(a -> a.getCOSObject()).filter(a -> !(a instanceof COSNull)).map(PDAppearanceEntry::new)
-                .collect(Collectors.toList());
-        for (PDAppearanceEntry entry : appreaceEntries) {
-            if (entry.isStream()) {
-                processStream(entry.getAppearanceStream());
-            } else {
-                for (PDAppearanceStream stream : entry.getSubDictionary().values()) {
-                    // TODO investigate this case with named dictionary
-                    processStream(stream);
-                }
-            }
-        }
-    }
-
-    @Override
-    public void accept(PDPage page) {
-        try {
-            this.processPage(page);
-            for (PDAnnotation annotation : page.getAnnotations()) {
-                processAnnotation(annotation);
-            }
-        } catch (IOException e) {
-            LOG.warn("Failed parse page, skipping and continuing with next.", e);
-        }
-    }
-
 }
